/**
 * Componente de select
 *
 * @author                  Pablo
 * @param onChange          Callback que será chamado quando um item for selecionado
 * @param placeholder       Texto principal do componente (obrigatório)
 * @param showMessage       Informa se a mensagem de erro é pra ser mostrada, caso seja é necessário passar valor true (opcional)
 * @param errorMessage      Mensagem de erro a ser passada (opcional)
 * @param items             Array com as opções do select com suas respectivas labels e values (obrigatório)
 * @param initialValue      Valor inicial para a seleção(opcional)
 *
 *
 * @example                 <SelectComponent
 *                           placeholder='Selecione uma categoria'
 *                           items={[{ name: 'name1', value: 'value1'}, { name: 'name2', value: 'value2' }]}
 *                           errorMessage='Campo Obrigatório'
 *                          />
 *
 */

import React, { useState } from 'react';
import { View, StyleSheet, Text } from 'react-native';
import {
  Header,
  Icon,
  Picker,
  Left,
  Body,
  Title,
  Right,
  Button,
} from 'native-base';
import FeatherIcon from 'react-native-vector-icons/Feather';
import colors from '../constants/colors';

export default function SelectComponent({
  onChange,
  placeholder,
  errorMessage,
  items,
  style,
  initialValue,
}) {
  const [error, setError] = useState(errorMessage);

  function renderItems() {
    return (
      items &&
      items.map(item => (
        <Picker.Item label={item.name} key={item.name} value={item.value} />
      ))
    );
  }

  function handleSelectedValue(value) {
    if (value) setError(false);
    else setError(true);
    if (onChange) onChange(value);
  }

  return (
    <View style={[styles.container, style]}>
      <Button style={styles.button}>
        <Picker
          selectedValue={initialValue}
          mode="dropdown"
          placeholder={placeholder}
          //Customização header dentro da seleção iOS
          renderHeader={backAction => (
            <Header style={{ backgroundColor: '#D51A5E' }}>
              <Left>
                <Button transparent onPress={backAction}>
                  <Icon name="arrow-back" style={{ color: '#fff' }} />
                </Button>
              </Left>
              <Body style={styles.headerPicker}>
                <Title style={{ color: '#fff' }}>{placeholder}</Title>
              </Body>
              <Right />
            </Header>
          )}
          //Customização header dentro da seleção iOS
          style={styles.picker}
          placeholder={placeholder}
          onValueChange={value => handleSelectedValue(value)}
        >
          {renderItems()}
          <Picker.Item label={placeholder} value={undefined} />
        </Picker>
        <FeatherIcon name="chevron-down" style={styles.icon} />
      </Button>
      <View style={styles.errorContainer}>
        <FeatherIcon
          name="alert-circle"
          size={24}
          style={[styles.errorIcon, !error && styles.hide]}
        />
        <Text style={[styles.errorMessage, !error && styles.hide]}>
          {errorMessage}
        </Text>
      </View>
    </View>
  );
}

const styles = StyleSheet.create({
  container: {
    marginBottom: 10,
    width: '100%',
  },
  icon: {
    color: colors.primary,
    backgroundColor: colors.background,
    borderRadius: 20,
    fontSize: 25,
    position: 'absolute',
    right: 0,
    marginRight: 7.5,
  },
  headerPicker: {
    flex: 3,
  },
  button: {
    borderColor: colors.primary,
    borderWidth: 2,
    backgroundColor: colors.background,
    borderRadius: 10,
    justifyContent: 'center',
  },
  errorContainer: {
    marginTop: '1%',
    display: 'flex',
    flexDirection: 'row',
  },
  errorMessage: {
    paddingLeft: '2%',
    fontSize: 16,
    fontWeight: 'bold',
    alignSelf: 'flex-start',
    color: colors.error,
  },
  errorIcon: {
    color: colors.error,
  },
  hide: {
    color: colors.transparent,
  },
});
