/**
 * Componente de card de tutorial da curadoria e de tutoriais aprovados
 *
 * @author             Pablo
 * @param author       autor do tutorial
 * @param title        título do tutorial
 * @param category     categoria do tutorial
 * @param date         data do tutorial
 * @param trusteeship  parametro que se passado como true tira o botão de remover/editar e adiciona a data e o botão de detalhes
 * @param action       parametro para indicar a ação que o botão de detalhes vai realizar
 * @param edit         parametro para redirecionar a tela para o tutorial a ser editado
 * @param remove       parametro para redirecionar a tela para o tutorial a ser removido
 * @example          <TutorialCard
 *                     author='José dos Santos'
 *                     title='O que é meme?'
 *                     edit={console.log('teste')}
 *                     remove={console.log('teste')}
 *                   />
 * @example          <TutorialCard
 *                     author='José dos Santos'
 *                     title='O que é meme?'
 *                     category='Conceitos'
 *                     date='02/04/2020'
 *                     trusteeship={true}
 *                     action={console.log('teste')}
 *                   />
 */

import React from 'react';
import {
  StyleSheet,
  Text,
  View,
  Platform,
  TouchableOpacity,
} from 'react-native';
import colors from '../constants/colors';

export default function TutorialCard({
  author,
  title,
  category,
  date,
  trusteeship = false,
  action,
  edit,
  remove,
}) {
  return (
    <TouchableOpacity
      style={styles.card}
      onPress={e => action()}
      disabled={!action}
    >
      <View style={styles.firstLine}>
        <Text style={styles.author}>{author}</Text>
        {trusteeship && <Text style={styles.date}>{date}</Text>}
      </View>

      <Text style={styles.placeholderText}>
        Título: <Text style={styles.insertedText}>{title}</Text>
      </Text>
      {trusteeship && (
        <>
          <Text style={styles.placeholderText}>
            Categoria: <Text style={styles.insertedText}>{category}</Text>
          </Text>
          <View style={styles.lastLine}>
            <View />
            <Text style={styles.details}>Detalhes</Text>
          </View>
        </>
      )}
      {!trusteeship && (
        <View style={styles.options}>
          <Text style={styles.button} onPress={edit}>
            Editar
          </Text>
          <Text style={styles.button} onPress={remove}>
            Remover
          </Text>
          <Text style={styles.details}>Detalhes</Text>
        </View>
      )}
    </TouchableOpacity>
  );
}

const styles = StyleSheet.create({
  button: {
    color: colors.textDisabled,
    textDecorationLine: 'underline',
    fontSize: 18,
  },
  card: {
    borderRadius: 4,
    backgroundColor: 'white',
    minHeight: 157,
    minWidth: '90%',
    elevation: 2,
    padding: 15,
    marginBottom: 15,
    ...Platform.select({
      ios: {
        shadowColor: colors.text,
        shadowOpacity: 0.25,
        shadowOffset: { width: 0, height: 1 },
        shadowRadius: 4,
      },
    }),
  },
  firstLine: {
    flexDirection: 'row',
    justifyContent: 'space-between',
  },
  author: {
    width: '70%',
    fontSize: 24,
    fontWeight: 'bold',
    color: colors.textDisabled,
  },
  date: {
    fontSize: 18,
    color: colors.textDisabled,
  },
  placeholderText: {
    fontWeight: 'bold',
    paddingTop: 15,
    fontSize: 18,
    color: colors.textDisabled,
  },
  insertedText: {
    fontSize: 18,
    color: colors.textDisabled,
    fontWeight: 'normal',
  },
  details: {
    fontSize: 18,
    color: colors.textDisabled,
    justifyContent: 'flex-end',

    textDecorationLine: 'underline',
  },
  options: {
    flexDirection: 'row',
    padding: 20,
    justifyContent: 'space-between',
  },
  lastLine: {
    flexDirection: 'row',
    justifyContent: 'space-between',
  },
});
