/**
 * Componente  que irá exibir um passo de um determinado tutorial.
 *
 * @author            Marlon Saldanha
 *
 * @param data        Dados completos do tutorial para serem exibidos nesta tela
 * @example           <TutorialComponent/>
 */

import React, { useState } from 'react';
import { View, Text, Image, StyleSheet } from 'react-native';
import WebView from 'react-native-webview';
import moment from "moment";
import APPS from '../constants/apps';

function StepComponent({ index, description, videoURL, imgURL }) {
  const hasVideo = (videoURL ?? '').length > 0;
  const hasImage = (imgURL ?? '').length > 0;

  return (
    <View>
      <Text style={styles.title}>Passo {index + 1}</Text>

      <Text style={styles.description}>{description}</Text>

      {hasVideo && (
        <WebView
          style={styles.video}
          source={{ uri: videoURL }}
          allowsInlineMediaPlayback
        />
      )}

      {hasImage && <Image style={styles.image} source={{ uri: imgURL }} />}
    </View>
  );
}

export default function TutorialComponent({ data }) {
  const {
    steps,
    tags,
    user,
    operatingSystem,
    operatingSystemVersion,
    appId,
    appVersion,
    date,
  } = data;

  const [appoioDate, setAppoioDate] = useState(undefined);

  React.useEffect(() => {
    if (date) {
      let dateParam = date.split(/[\s-:]/);
      dateParam[1] = (parseInt(dateParam[1], 10) - 1).toString();

      const formattedDate = moment(new Date(...dateParam)).format("DD/MM/YYYY");
      setAppoioDate(formattedDate);
    }
  }, [date]);

  let versions = null;
  if (operatingSystem) {
    const versionOS = operatingSystemVersion
      ? ` ${operatingSystemVersion}`
      : '';
    versions = `${operatingSystem}${versionOS}`;

    if (appId) {
      const appName = APPS.find(app => app.id === appId).name;
      const versionApp = appVersion ? ` ${appVersion}` : '';
      versions = `${appName}${versionApp} no ${versions}`;
    }
  }

  return (
    <View style={styles.container}>
      {steps &&
        steps.map((step, index) => (
          <StepComponent key={index + ""} {...step} index={index} />
        ))}

      <View style={styles.tagContainer}>
        {tags &&
          tags.map(tag => (
            <Text key={tag.name} style={styles.tag}>
              #{tag.name}
            </Text>
          ))}
      </View>

      {user && (
        <View style={styles.authorContainer}>
          <Text style={styles.author}>Autor: {user.name}</Text>
          <Text style={styles.createdAt}> em {appoioDate}</Text>
        </View>
      )}

      {versions && (
        <View style={styles.versionsContainer}>
          <Text style={styles.version}>Versões: {versions}</Text>
        </View>
      )}
    </View>
  );
}

const styles = StyleSheet.create({
  container: {
    marginBottom: 50,
  },
  title: {
    fontWeight: 'bold',
    fontSize: 20,
    color: colors.textDisabled,
    marginBottom: 16,
  },
  description: {
    textAlign: 'justify',
    fontWeight: '400',
    fontSize: 18,
    color: '#4F4F4F',
    marginBottom: 16,
  },
  image: {
    width: '100%',
    // o RN precisa saber dessas dimensões, se não a imagem não é carregada
    height: 300,
    marginBottom: 16,
  },
  video: {
    width: '100%',
    height: 400,
    marginBottom: 16,
  },
  tagContainer: {
    flexDirection: 'row',
    marginBottom: 16,
  },
  tag: {
    fontWeight: '400',
    fontSize: 20,
    color: colors.textDisabled,
    marginRight: 5,
  },
  authorContainer: {
    flexDirection: 'row',
    marginBottom: 8,
  },
  author: {
    fontWeight: '400',
    fontSize: 16,
    color: colors.textDisabled,
  },
  createdAt: {
    fontWeight: '400',
    fontSize: 16,
    color: colors.textDisabled,
  },
  versionsContainer: {
    flexDirection: 'row',
  },
  version: {
    fontWeight: '400',
    fontSize: 16,
    color: colors.textDisabled,
  },
});
