/**
 * Tela Seleção de Aplicativos Instalados
 *
 * @author            Eduardo Cardoso
 * @example           <AppSelectionScreen/>
 */

import React, { useState } from 'react';
import { StyleSheet, View, Text } from 'react-native';
import colors from '../constants/colors';
import { StackActions } from '@react-navigation/native';

import HeaderComponent from '../components/HeaderComponent';
import BodyComponent from '../components/BodyComponent';
import ButtonComponent from '../components/ButtonComponent';
import CardComponent from '../components/CardComponent';
import LoaderComponent from '../components/LoaderComponent';
import APPS from '../constants/apps';
import { updateInstalledApps } from '../api';

export default function AppSelectionScreen({ navigation, route }) {
  const [isLoading, setIsLoading] = React.useState(false);
  const [appsInstalled, setAppInstalled] = useState(
    route.params.allAppsInstalled,
  );

  async function send() {
    try {
      setIsLoading(!isLoading);
      const response = await updateInstalledApps(appsInstalled);
      setIsLoading(!isLoading);
      console.log(response.data);
    } catch (error) {
      console.warn(error);
    }
    navigation.dispatch(StackActions.replace('Root'));
  }

  function checkAlreadyAppsInstalled(id) {
    return appsInstalled?.includes(id);
  }

  function cardOnChange(selected, id) {
    !selected ? addApp(id) : removeApp(id);
  }

  function removeApp(id) {
    setAppInstalled(appsInstalled.filter(value => value !== id));
  }

  function addApp(id) {
    setAppInstalled([...appsInstalled, id]);
  }

  return isLoading ? (
    <LoaderComponent isActivityIndicator="false" />
  ) : (
    <View style={styles.screen}>
      <HeaderComponent
        leftButton={route?.params?.allAppsInstalled}
        leftButtonAction={() => navigation.goBack()}
        rightButton="Pular"
        rightButtonAction={e => navigation.navigate('HomeScreen')}
      >
        <Text style={styles.headerDescription}>
          Selecione o(s) aplicativo(s) que você tem instalado no seu celular.
        </Text>
      </HeaderComponent>

      <BodyComponent
        buttonAction={send}
        buttonText="Salvar"
        buttonBackgroundColor={colors.primary}
        buttonTextColor={colors.textWhite}
      >
        <View style={styles.rows}>
          {APPS.map(({ id, name, image }) => {
            return (
              <CardComponent
                key={id}
                id={id}
                name={name}
                startSelected={checkAlreadyAppsInstalled(id)}
                onStateChange={cardOnChange}
                image={image}
              />
            );
          })}
        </View>
      </BodyComponent>
    </View>
  );
}

const styles = StyleSheet.create({
  screen: {
    flex: 1,
    backgroundColor: colors.primary,
  },
  rows: {
    flexWrap: 'wrap',
    flexDirection: 'row',
    justifyContent: 'space-between',
  },
  header: {
    alignItems: 'center',
    justifyContent: 'center',
    color: colors.textWhite,
    fontSize: 30,
    fontWeight: 'bold',
  },
  headerDescription: {
    alignItems: 'center',
    textAlign: 'center',
    justifyContent: 'center',
    color: colors.textWhite,
    fontSize: 22,
  },
});
