/**
 * Tela de modelo com um componente de modelo
 *
 * @author            Enzo Russo, Felipe Hamester, Marlon Saldanha
 * @example           <AppoioBasicScreen/>
 */

import React, { useState, useEffect } from 'react';
import { StyleSheet, View, Text, Alert } from 'react-native';
import APPS from '../constants/apps';
import Header from '../components/HeaderComponent';
import Body from '../components/BodyComponent';
import InputText from '../components/InputTextComponent';
import SelectComponent from '../components/SelectComponent';
import colors from '../constants/colors';
import * as API from '../api';

const categories = [
  { name: 'Celular', value: 'celular' },
  { name: 'Aplicativos', value: 'aplicativos' },
  { name: 'Conceitos', value: 'conceitos' },
];

export default function AppoioBasicScreen({ route, navigation }) {
  const [chosenOption, setChosenOption] = useState(null);
  const [name, setName] = useState('');
  const [app, setApp] = useState(0);
  const [appVersion, setAppVersion] = useState('');
  const [os, setOS] = useState('');
  const [osVersion, setOSVersion] = useState('');
  const [tagList, setTagList] = useState([]);

  const apps = APPS.map(app => ({ name: app.name, value: app.id }));

  function isValidData() {
    if (!name.length) return false;
    if (!chosenOption) return false;

    if (chosenOption === 'celular') {
      if (!os.length) return false;
    }

    if (chosenOption === 'aplicativos') {
      if (!app) return false;
      if (!os.length) return false;
    }

    return true; // 'conceitos' ou os obrigatórios preenchidos
  }

  async function goNext() {
    const data = {
      name,
      category: chosenOption,
      appId: app,
      appVersion,
      os,
      osVersion,
      tags: tagList,
    };

    navigation.navigate('AppoioStepScreen', { data });
  }

  async function checkSignedIn() {
    const isSignedIn = await API.isLoggedIn();
    if (isSignedIn) {
      return;
    }

    Alert.alert(
      'Você não está logado',
      'Você deve fazer login ou criar uma conta para cadastrar um tutorial.',
      [
        {
          text: 'Ir para login',
          onPress: () => navigation.navigate('LoginScreen'),
        },
        {
          text: 'Cancelar',
          onPress: () => navigation.jumpTo('Root'),
          style: 'cancel',
        },
      ],
    );
  }

  useEffect(() => {
    return navigation.addListener('focus', checkSignedIn);
  }, []);

  return (
    <View style={styles.screen}>
      <Header large>
        <Text style={styles.title}>
          Enviar um <Text style={styles.textBold}>Appoio</Text>
        </Text>
        <Text style={styles.descriptionText}>
          Adicione informações básicas sobre o{' '}
          <Text style={styles.textBold}>Appoio</Text> que deseja criar{' '}
        </Text>
      </Header>

      <Body
        buttonAction={goNext}
        buttonDisabled={!isValidData()}
        buttonText="Próximo"
        buttonBackgroundColor={colors.primary}
        buttonTextColor={colors.textWhite}
      >
        <View>
          <InputText
            placeholder="Nome do Appoio*"
            onChangeText={name => setName(name)}
            errorMessage="Campo obrigatório"
          />
          <SelectComponent
            errorMessage="Nenhum item foi selecionado"
            onChange={setChosenOption}
            placeholder="Selecionar categoria*"
            items={categories}
          />
          {chosenOption === 'aplicativos' && (
            <>
              <SelectComponent
                errorMessage="Nenhum item foi selecionado"
                onChange={selected => setApp(selected)}
                placeholder="Selecionar nome do aplicativo*"
                items={apps}
              />
              <InputText
                onChangeText={version => setAppVersion(version)}
                placeholder="Versão do Aplicativo"
              />
            </>
          )}
          {(chosenOption === 'celular' || chosenOption === 'aplicativos') && (
            <>
              <InputText
                onChangeText={os => setOS(os)}
                placeholder="Sistema Operacional*"
                errorMessage="Campo obrigatório"
              />
              <InputText
                onChangeText={version => setOSVersion(version)}
                placeholder="Versão do Sistema Operacional"
              />
            </>
          )}
          {chosenOption && (
            <>
              <InputText
                placeholder="Tags"
                tagType
                onAddTag={tag => setTagList([...tagList, tag])}
              />
            </>
          )}
        </View>
      </Body>
    </View>
  );
}
const styles = StyleSheet.create({
  screen: {
    flex: 1,
    backgroundColor: colors.primary,
    alignItems: 'center',
  },
  title: {
    color: colors.textWhite,
    fontSize: 30,
    textAlign: 'center',
  },
  textBold: {
    fontWeight: 'bold',
  },
  descriptionText: {
    color: colors.textWhite,
    fontSize: 22,
    textAlign: 'center',
  },
});
