/**
 * Tela de passos de um tutorial, tanto para usuário comum quanto pra administrador.
 *
 * @author            Joao Leao, Bernardo de Cesaro
 * @example           <AppoioStepScreen/>
 */

import React, { useEffect, useState } from 'react';
import { StyleSheet, View, Text, Alert, AsyncStorage } from 'react-native';
import { CommonActions } from '@react-navigation/native';
import Header from '../components/HeaderComponent';
import Body from '../components/BodyComponent';
import LoaderComponent from '../components/LoaderComponent';
import Button from '../components/ButtonComponent';
import StepComponent from '../components/StepComponent';
import { registerAppoio } from '../api';
import colors from '../constants/colors';

export default function AppoioStepScreen({ route, navigation }) {
  const [isLoading, setIsLoading] = React.useState(false);
  const [steps, setSteps] = React.useState([
    { order: 0, description: '', videoURL: '', imgURL: '' },
  ]);
  const [isAdmin, setIsAdmin] = useState(null);

  React.useEffect(() => {
    (async () => {
      let isAdmin = null;
      try {
        isAdmin = (await AsyncStorage.getItem('isAdmin')) || null;
      } catch (error) {
        console.log(error.message);
      }
      setIsAdmin(isAdmin === 'true');
    })();
  }, []);

  async function send() {
    try {
      setIsLoading(true);
      await registerAppoio({
        ...route.params.data,
        steps,
      });
      setIsLoading(false);

      if (isAdmin) {
        // duas navegações
        // primeiro, resetar a stack da aba de novo appoio
        navigation.dispatch(
          CommonActions.reset({
            index: 0,
            routes: [{ name: 'AppoioBasicScreen' }],
          }),
        );

        // depois, ir para a tela de aprovados
        navigation.navigate('ApprovedScreen');

        Alert.alert('Adicionado!', 'O appoio foi adicionado à coleção!');
      } else {
        navigation.navigate('AppoioConfirmationScreen');
      }
    } catch (error) {
      setIsLoading(false);
      Alert.alert(error.title, error.message, [{ text: 'OK' }]);
    }
  }

  function isValidData() {
    for (let i = 0; i < steps.length; i++) {
      if (steps[i].description.length == 0) return false;
    }
    return true;
  }
  function handleDescription(text, index) {
    const array = [...steps];
    array[index] = {
      ...array[index],
      description: text,
    };
    setSteps(array);
  }
  function handleVideo(text, index) {
    const array = [...steps];
    array[index] = {
      ...array[index],
      videoURL: text,
    };
    setSteps(array);
  }
  function handleImage(img, index) {
    const array = [...steps];
    const step = array[index];
    array[index] = {
      ...step,
      imgURL: {
        ...img,
        name: `${step.order}.${img.uri.split('.').pop()}`,
      },
    };
    setSteps(array);
  }

  const reset = () => {
    navigation.dispatch(
      CommonActions.reset({
        index: 0,
        routes: [{ name: 'AppoioBasicScreen' }],
      }),
    );
  };

  function handleAdd() {
    setSteps([
      ...steps,
      {
        order: steps.length,
        description: '',
        videoURL: '',
        imgURL: '',
      },
    ]);
  }
  function handleDelete(index) {
    let filtered = steps
      .filter(item => item.order !== index)
      .map(item => {
        if (item.order > index) {
          return {
            ...item,
            order: item.order - 1,
          };
        }
        return item;
      });
    setSteps(filtered);
  }

  return isLoading ? (
    <LoaderComponent />
  ) : (
    <View style={styles.screen}>
      <Header
        large
        leftButton
        rightButton="Cancelar"
        leftButtonAction={e => navigation.navigate('AppoioBasicScreen')}
        rightButtonAction={e => reset()}
      >
        <Text style={styles.title}>
          Enviar um <Text style={styles.textBold}>Appoio</Text>
        </Text>
        <Text style={styles.descriptionText}>
          Adicione o passo a passo do{' '}
          <Text style={styles.textBold}>Appoio</Text> que deseja criar{' '}
        </Text>
      </Header>

      <Body
        buttonAction={send}
        buttonDisabled={!isValidData()}
        buttonText="Enviar Appoio"
        buttonBackgroundColor={colors.primary}
        buttonTextColor={colors.textWhite}
        divisor
      >
        {steps.map((item, index) => (
          <StepComponent
            key={index}
            index={index}
            item={item}
            handleDescription={handleDescription}
            handleVideo={handleVideo}
            handleImage={handleImage}
            handleDelete={steps.length > 1 ? handleDelete : null}
          />
        ))}
        <View style={styles.button}>
          <Button
            text="Adicionar Passo"
            bordered
            icon="plus"
            action={handleAdd}
          />
        </View>
      </Body>
    </View>
  );
}
const styles = StyleSheet.create({
  screen: {
    flex: 1,
    backgroundColor: colors.primary,
    alignItems: 'center',
  },
  title: {
    color: colors.textWhite,
    fontSize: 30,
    textAlign: 'center',
  },
  textBold: {
    fontWeight: 'bold',
  },
  descriptionText: {
    color: colors.textWhite,
    fontSize: 22,
    textAlign: 'center',
  },
  button: {
    alignItems: 'center',
  },
});
