/**
 * Tela de modelo com um componente de modelo
 *
 * @author            Felipe Hamester, Pablo e Joao Leão
 * @example           <AppoioBasicScreen/>
 */

import React, { useState, useEffect } from 'react';
import { StyleSheet, View, Text, Alert } from 'react-native';
import APPS from '../constants/apps';
import Header from '../components/HeaderComponent';
import Body from '../components/BodyComponent';
import InputText from '../components/InputTextComponent';
import SelectComponent from '../components/SelectComponent';
import colors from '../constants/colors';
import API from '../api';

const categories = [
  { name: 'Celular', value: 'celular' },
  { name: 'Aplicativos', value: 'aplicativos' },
  { name: 'Conceitos', value: 'conceitos' },
];

export default function EditTutorialInfoScreen({ route, navigation }) {
  const [tutorialId, setTutorialId] = useState(null);
  const [chosenOption, setChosenOption] = useState(null);
  const [name, setName] = useState('');
  const [app, setApp] = useState(0);
  const [appVersion, setAppVersion] = useState('');
  const [os, setOS] = useState('');
  const [osVersion, setOSVersion] = useState('');
  const [tagList, setTagList] = useState([]);
  const [steps, setSteps] = useState([]);

  const apps = APPS.map(app => ({ name: app.name, value: app.id }));

  React.useEffect(() => {
    async function fetchApproved() {
      try {
        const tutorial = await API.get(`/tutorial/get/${route.params.id}`);

        setApp(tutorial.data.data.appId);
        setChosenOption(tutorial.data.data.category);
        setAppVersion(tutorial.data.data.appVersion);
        setOS(tutorial.data.data.operatingSystem);
        setOSVersion(tutorial.data.data.operatingSystemVersion);
        setName(tutorial.data.data.appoioName);

        const array = [...tutorial.data.data.steps];
        for (let i = 0; i < steps.length; i++) {
          array[i] = {
            ...array[i],
            order: i,
          };
        }
        setSteps(array);

        const listOfObjects = tutorial.data.data.tags.map(item => item.name);
        setTagList([...listOfObjects]);
      } catch (error) {
        console.warn(error);
      }
      setTutorialId(route.params.id);
    }

    if (tutorialId != route.params.id) fetchApproved();
  });

  function isValidData() {
    if (!name.length) return false;
    if (!chosenOption) return false;

    if (chosenOption === 'celular') {
      if (!os.length) return false;
    }

    if (chosenOption === 'aplicativos') {
      if (!app) return false;
      if (!os.length) return false;
    }

    return true; // 'conceitos' ou os obrigatórios preenchidos
  }

  async function goNext() {
    const data = {
      tutorialId,
      name,
      chosenOption,
      app,
      appVersion,
      os,
      steps,
      osVersion,
      tagList,
    };

    navigation.navigate('EditTutorialStepsScreen', { data });
  }

  return (
    <View style={styles.screen}>
      <Header large leftButton leftButtonAction={() => navigation.goBack()}>
        <Text style={styles.title}>
          Altere um <Text style={styles.textBold}>Appoio</Text>
        </Text>
        <Text style={styles.descriptionText}>
          Edite informações básicas sobre o{' '}
          <Text style={styles.textBold}>Appoio</Text> que deseja mudar{' '}
        </Text>
      </Header>

      <Body
        buttonAction={goNext}
        buttonText="Próximo"
        buttonBackgroundColor={colors.primary}
        buttonTextColor={colors.textWhite}
      >
        <View>
          <InputText
            value={name}
            placeholder="Nome do Appoio*"
            onChangeText={name => setName(name)}
          />
          <SelectComponent
            initialValue={chosenOption}
            onChange={setChosenOption}
            placeholder="Selecionar categoria*"
            items={categories}
          />
          {chosenOption === 'aplicativos' && (
            <>
              <SelectComponent
                initialValue={app}
                onChange={selected => setApp(selected)}
                placeholder="Selecionar nome do aplicativo*"
                items={apps}
              />
              <InputText
                value={appVersion}
                onChangeText={version => setAppVersion(version)}
                placeholder="Versão do Aplicativo"
              />
            </>
          )}
          {(chosenOption === 'celular' || chosenOption === 'aplicativos') && (
            <>
              <InputText
                value={os}
                onChangeText={os => setOS(os)}
                placeholder="Sistema Operacional*"
              />
              <InputText
                value={osVersion}
                onChangeText={version => setOSVersion(version)}
                placeholder="Versão do Sistema Operacional"
              />
            </>
          )}
          {chosenOption && (
            <>
              <InputText
                tags={tagList}
                placeholder="Tags"
                tagType
                onAddTag={tag => setTagList([...tagList, tag])}
              />
            </>
          )}
        </View>
      </Body>
    </View>
  );
}
const styles = StyleSheet.create({
  screen: {
    flex: 1,
    backgroundColor: colors.primary,
    alignItems: 'center',
  },
  title: {
    color: colors.textWhite,
    fontSize: 30,
    textAlign: 'center',
  },
  textBold: {
    fontWeight: 'bold',
  },
  descriptionText: {
    color: colors.textWhite,
    fontSize: 22,
    textAlign: 'center',
  },
});
