/**
 * Tela de modelo com um componente de modelo
 *
 * @author            João Leão, Arthur Henz e Felipe Hamester
 * @example           <ModelScreen/>
 */

import React from 'react';
import {
  StyleSheet,
  View,
  Image,
  Text,
  Platform,
  Dimensions,
  AsyncStorage,
} from 'react-native';
import api from '../api';

import TabSelectionComponent from '../components/TabSelectionComponent';
import BodyComponent from '../components/BodyComponent';
import HeaderComponent from '../components/HeaderComponent';
import ListComponent from '../components/ListComponent';
import colors from '../constants/colors';
import AppButtonComponent from '../components/AppButtonComponent';
import ButtonComponent from '../components/ButtonComponent';
import SearchBarComponent from '../components/SearchBarComponent';

import APPS from '../constants/apps';

export default function HomeScreen({ navigation }) {
  const [selectedTab, setSelectedTab] = React.useState(0);
  const [data, setData] = React.useState([]);
  const [dataCelular, setDataCelular] = React.useState([]);
  const [allAppsInstalled, setAllAppsInstalled] = React.useState([]);
  const [appsInstalled, setInstalled] = React.useState([]);
  const [appsNotInstalled, setNotInstalled] = React.useState([]);
  const [searchText, setSearchText] = React.useState('');
  const [filteredData, setFilteredData] = React.useState([]);
  const [noResultMessage, setNoResultMessage] = React.useState('');
  const [isLogged, setIsLogged] = React.useState(false);

  async function goBack() {
    navigation.navigate('AppSelectionScreen', { allAppsInstalled });
  }

  async function handleSearch() {
    if (searchText.length > 0) {
      const response = await api.get(`tutorial/search/${searchText}`);
      console.log('tamanho - ', response.data.data.length);
      if (response.data.data.length > 0) {
        setNoResultMessage('');
        setFilteredData(response.data.data);
      } else {
        setNoResultMessage('Nenhum tutorial foi retornado.');
      }

      if (response.data.status === 500) {
        Alert.alert(
          'Falha ao logar',
          'Houve um problema ao tentar fazer login. Tente novamente mais tarde.',
        );
      } else {
        //TODO redirecionar para a rota de admin ou usuário comum.
        console.log(response.data.data);
      }
    }
  }

  function handleChangeSearchText(searchText) {
    if (!searchText.length) {
      setFilteredData([]);
      setNoResultMessage('');
      setSearchText('');
    } else setSearchText(searchText);
  }

  function filterTutorialsForOS(tutorials) {
    return (tutorials ?? []).filter(tutorial => {
      const os = (tutorial.operatingSystem ?? '').trim();
      if (os.length === 0) {
        return true;
      }

      return os.toLowerCase() === Platform.OS;
    });
  }

  React.useEffect(() => {
    async function isLogged() {
      try {
        const isLogged = await AsyncStorage.getItem('userId');
        setIsLogged(!!isLogged);
      } catch (error) {
        console.warn(error);
      }
    }
    async function fetchApps() {
      try {
        const APPS = await api.get(`/app/all`);
        const appsInstalled = APPS.data.data.Installed;
        const appsNotInstalled = APPS.data.data.NotInstalled;
        if (appsInstalled?.length != 0) setInstalled(appsInstalled);
        else setInstalled([]);

        if (appsNotInstalled?.length != 0) setNotInstalled(appsNotInstalled);
        else setNotInstalled([]);

        const allInstalledRes = await api.get('/app/installed');
        const allInstalled = allInstalledRes.data.data;

        if (allInstalled.length != 0) setAllAppsInstalled(allInstalled);
        else setAllAppsInstalled([]);
      } catch (error) {
        console.warn(error);
      }
    }
    async function fetchData() {
      try {
        const response = await api.get(`/tutorial/categories/1`);
        setData(response.data.data);
        setDataCelular(filterTutorialsForOS(response.data.data.celular));
      } catch (error) {
        console.warn(error);
      }
    }
    fetchApps();
    fetchData();
    isLogged();
  }, [selectedTab]);

  const emptyMessage = (
    text = 'Não existem tutoriais desta categoria ainda.',
  ) => (
    <View style={styles.emptyMessageContainer}>
      <Text style={styles.emptyMessage}>{text}</Text>
    </View>
  );

  const width = Dimensions.get('screen').width - 40;
  const cardSize = width * 0.3;

  return (
    <View style={styles.screen}>
      <HeaderComponent large>
        <Image
          style={{
            alignSelf: 'center',
            width: 90,
            height: 46,
            marginBottom: 10,
          }}
          source={require('../../assets/logo-p.png')}
        />
        <SearchBarComponent
          handleClick={handleSearch}
          sendSearch={value => handleChangeSearchText(value)}
        />
      </HeaderComponent>

      <BodyComponent notSpaced>
        {!!noResultMessage && emptyMessage(noResultMessage)}
        {!noResultMessage && filteredData.length > 0 ? (
          <ListComponent
            appoios={filteredData}
            action={id => navigation.navigate('Tutorial', { id })}
          />
        ) : (
          !noResultMessage && (
            <>
              <TabSelectionComponent
                tabSelected={selectedTab}
                onPress={index => setSelectedTab(index)}
              >
                <View title="APLICATIVOS" style={styles.content} />
                <View title="CELULAR" style={styles.content} />
                <View title="CONCEITOS" style={styles.content} />
              </TabSelectionComponent>

              {selectedTab == 0 &&
                (appsInstalled.length != 0 || appsNotInstalled.length != 0 ? (
                  <View>
                    {isLogged && (
                      <View>
                        <Text style={styles.message}>
                          Aplicativos instalados
                        </Text>
                        {appsInstalled.length == 0 &&
                          emptyMessage('Nenhum aplicativo adicionado.')}
                        <View style={styles.aplicativos}>
                          {appsInstalled.map(id => {
                            let name = '';
                            let image = '';
                            for (let i = 0; i < APPS.length; i++) {
                              if (id == APPS[i].id) {
                                name = APPS[i].name;
                                image = APPS[i].image;
                              }
                            }
                            return (
                              <AppButtonComponent
                                key={id}
                                action={e =>
                                  navigation.navigate('TutorialListScreen', {
                                    id,
                                    name,
                                  })
                                }
                                name={name}
                                image={image}
                              />
                            );
                          })}
                          {appsInstalled.length % 3 != 0 && (
                            <View
                              style={{ width: cardSize, height: cardSize }}
                            />
                          )}
                        </View>
                        <View style={styles.buttonContainer}>
                          <ButtonComponent
                            text={
                              appsInstalled.length !== 0
                                ? 'Adicionar mais aplicativos'
                                : 'Adicionar aplicativos'
                            }
                            backgroundColor={colors.primary}
                            textColor={colors.textWhite}
                            action={goBack}
                          />
                        </View>
                      </View>
                    )}
                    {appsNotInstalled.length != 0 && (
                      <View style={styles.grayBackground}>
                        <Text style={styles.message}>
                          Todos os aplicativos com tutorial
                        </Text>
                        <View style={styles.aplicativos}>
                          {appsNotInstalled.map(id => {
                            let name = '';
                            let image = '';
                            for (let i = 0; i < APPS.length; i++) {
                              if (id == APPS[i].id) {
                                name = APPS[i].name;
                                image = APPS[i].image;
                              }
                            }
                            return (
                              <AppButtonComponent
                                key={id}
                                action={e =>
                                  navigation.navigate('TutorialListScreen', {
                                    id,
                                    name,
                                  })
                                }
                                name={name}
                                image={image}
                              />
                            );
                          })}
                          {appsNotInstalled.length % 3 != 0 && (
                            <View
                              style={{ width: cardSize, height: cardSize }}
                            />
                          )}
                        </View>
                      </View>
                    )}
                  </View>
                ) : (
                  emptyMessage()
                ))}
              {selectedTab == 1 &&
                ((dataCelular ?? []).length > 0 ? (
                  <ListComponent
                    appoios={dataCelular}
                    action={id => navigation.navigate('Tutorial', { id })}
                  />
                ) : (
                  emptyMessage()
                ))}
              {selectedTab == 2 &&
                (data.conceitos ? (
                  <ListComponent
                    appoios={data.conceitos}
                    action={id => navigation.navigate('Tutorial', { id })}
                  />
                ) : (
                  emptyMessage()
                ))}
            </>
          )
        )}
      </BodyComponent>
    </View>
  );
}
const styles = StyleSheet.create({
  screen: {
    flex: 1,
    backgroundColor: colors.primary,
  },
  emptyMessage: {
    color: colors.textDisabled,
    fontSize: 20,
    fontWeight: 'bold',
    textAlign: 'center',
    alignSelf: 'center',
  },
  message: {
    marginVertical: 10,
    marginHorizontal: 15,
    color: '#000000',
    fontSize: 20,
    fontWeight: 'bold',
    justifyContent: 'center',
  },
  emptyMessageContainer: {
    marginVertical: '10%',
    justifyContent: 'center',
  },
  aplicativos: {
    flexDirection: 'row',
    flexWrap: 'wrap',
    justifyContent: 'space-between',
  },
  buttonContainer: {
    alignItems: 'center',
  },
  body: {
    padding: 0,
    paddingTop: 20,
  },
  appsInstalledSection: {
    paddingBottom: 20,
  },
  grayBackground: {
    backgroundColor: colors.backgroundSection,
    borderRadius: 15,
  },
});
